/* $Workfile: OtxBurstD.h $   $Revision: 7 $    $Modtime: 12/12/03 5:19p $  */

#ifndef OTX_BURST_DEF_H
#define OTX_BURST_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxBurstD

  Copyright (C) 1998, 1999, 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBurstD | Constants, Macros, and Types for the DMA Burst Device Management Functions

  @contents2
  OtxBurstD.h |

  @index enum struct type | OtxBurstD

  @contents2
  OTX DMA Burst Device Management Macros, Constants, and Types |

  @head3 OtxBurstXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxBurstD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif

/*---------------------------------------------------------------------------*\
  @enum 
    DSP Device Attributes
\*---------------------------------------------------------------------------*/
enum OtxBurstDeviceAttributesE {
  OTX_ATTR_BURST_TRIGGER                  = OTX_ATTR_END + 1,   // @emem (OTX_ATTRIB_UINT32) Read/Write. DMA transfer signal trigger value (1,2,4,8,16,32)
  OTX_ATTR_BURST_TX_BUFFER_SIZE           = OTX_ATTR_END + 2,   // @emem (OTX_ATTRIB_UINT32) Read only. DMA Send buffer size
  OTX_ATTR_BURST_MAX_TIMESLOTS            = OTX_ATTR_END + 3,   // @emem (OTX_ATTRIB_UINT32) Read only. DMA Buffer max timeslots per transfer
  OTX_ATTR_BURST_STAT_RECV_STARTS         = OTX_ATTR_END + 4,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers initiated
  OTX_ATTR_BURST_STAT_RECV_COMPLETES      = OTX_ATTR_END + 5,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers completed
  OTX_ATTR_BURST_STAT_RECV_PARTIAL        = OTX_ATTR_END + 6,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv partial transfer due to framemask
  OTX_ATTR_BURST_STAT_RECV_FULL           = OTX_ATTR_END + 7,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of max dma size transfers
  OTX_ATTR_BURST_STAT_RECV_ABORTS         = OTX_ATTR_END + 8,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers aborts
  OTX_ATTR_BURST_STAT_RECV_AMOUNT         = OTX_ATTR_END + 9,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv amount of data transfered
  OTX_ATTR_BURST_STAT_RECV_ERRORS         = OTX_ATTR_END + 10,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of processing errors
  OTX_ATTR_BURST_STAT_RECV_OURUNS         = OTX_ATTR_END + 11,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv amount of over/under runs
  OTX_ATTR_BURST_STAT_RECV_DMABUSY        = OTX_ATTR_END + 12,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of DMA busy occurances
  OTX_ATTR_BURST_STAT_RECV_NOTIFY         = OTX_ATTR_END + 13,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv logical device notifies
  OTX_ATTR_BURST_STAT_RECV_NOTIFY_PARTIAL = OTX_ATTR_END + 14,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv logical device notifies - partial
  OTX_ATTR_BURST_STAT_SEND_STARTS         = OTX_ATTR_END + 15,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers initiated
  OTX_ATTR_BURST_STAT_SEND_COMPLETES      = OTX_ATTR_END + 16,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers completed
  OTX_ATTR_BURST_STAT_SEND_PARTIAL        = OTX_ATTR_END + 17,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send partial transfer due to framemask
  OTX_ATTR_BURST_STAT_SEND_FULL           = OTX_ATTR_END + 18,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of max dma size transfers
  OTX_ATTR_BURST_STAT_SEND_ABORTS         = OTX_ATTR_END + 19,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers aborts
  OTX_ATTR_BURST_STAT_SEND_AMOUNT         = OTX_ATTR_END + 20,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of data transfered
  OTX_ATTR_BURST_STAT_SEND_ERRORS         = OTX_ATTR_END + 21,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of processing errors
  OTX_ATTR_BURST_STAT_SEND_OURUNS         = OTX_ATTR_END + 22,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of over/under runs
  OTX_ATTR_BURST_STAT_SEND_DMABUSY        = OTX_ATTR_END + 23,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of DMA busy occurances
  OTX_ATTR_BURST_STAT_SEND_NOTIFY         = OTX_ATTR_END + 24,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send logical device notifies
  OTX_ATTR_BURST_STAT_SEND_NOTIFY_PARTIAL = OTX_ATTR_END + 25,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send logical device notifies - partial

  OTX_ATTR_BURST_END                      = OTX_ATTR_END + 26
};

typedef enum OtxBurstDeviceAttributesE OtxBurstDeviceAttributesE;

/*---------------------------------------------------------------------------*\
  @enum
    DSP Event Codes
\*---------------------------------------------------------------------------*/
enum OtxBurstEventCodesE {
  OTX_BURST_EC_BUFFER_OVERRUN             = 0x00,   // @emem Receiver data overrun error - data lost
  OTX_BURST_EC_BUFFER_UNDERRUN            = 0x01,   // @emem Sender data underrun error
  OTX_BURST_END_OF_EVENT_CODES
};
typedef enum OtxBurstEventCodesE OtxBurstEventCodesE;


#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999, 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_BURST_DEF_H
